@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.047'; # VERSION
+our $VERSION = '0.048'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -20,7 +20,8 @@ sub opt_spec {
 
     return (
         [ 'dryrun'      => 'Do not commit any changes'         ],
-        [ 'norecurse'   => 'Do not recursively pull prereqs'   ],
+        [ 'message|m=s' => 'Message to describe the change'    ],
+        [ 'norecurse|n' => 'Do not recursively pull prereqs'   ],
         [ 'pin'         => 'Pin all the packages to the stack' ],
         [ 'stack|s=s'   => 'Put packages into this stack'      ],
     );
@@ -50,7 +51,7 @@ App::Pinto::Command::pull - pull archives from upstream repositories
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -96,9 +97,22 @@ impact the stack.
 
 =item --norecurse
 
+=item -n
+
 Do not recursively pull any distributions required to satisfy
 prerequisites for the targets.
 
+=item --message=TEXT
+
+=item -m TEXT
+
+Use TEXT as the revision history log message.  If you do not use
+C<--message> option, then you will be prompted to enter the message
+via your text editor.  Use the C<EDITOR> or C<VISUAL> environment
+variables to control which editor is used.  A log message is not
+required whenever the C<--dryrun> option is set, or if the action did
+not yield any changes to the repository.
+
 =item --pin
 
 Pins the packages to the stack, so they cannot be changed until you
