@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.047'; # VERSION
+our $VERSION = '0.048'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,7 +19,8 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'stack|s=s' => 'Stack from which to unpin the target' ],
+        [ 'message|m=s' => 'Message to describe the change'       ],
+        [ 'stack|s=s'   => 'Stack from which to unpin the target' ],
     );
 }
 
@@ -47,7 +48,7 @@ App::Pinto::Command::unpin - free packages that have been pinned
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -83,6 +84,17 @@ or ';') will be ignored.
 
 =over 4
 
+=item --message=TEXT
+
+=item -m TEXT
+
+Use TEXT as the revision history log message.  If you do not use
+C<--message> option, then you will be prompted to enter the message
+via your text editor.  Use the C<EDITOR> or C<VISUAL> environment
+variables to control which editor is used.  A log message is not
+required whenever the C<--dryrun> option is set, or if the action did
+not yield any changes to the repository.
+
 =item --stack=NAME
 
 Unpins the package on the stack with the given NAME.  Defaults to the
